@@ -173,6 +173,21 @@ rm -f /etc/apt/sources.list.d/20_ucs-online-component.list.upgrade510.bak
 rm -f /etc/apt/sources.list.d/15_ucs-online-version.list.upgrade520.bak
 rm -f /etc/apt/sources.list.d/20_ucs-online-component.list.upgrade520.bak
 
+# univention/ucs#2636 Bug 57896
+# fix samba deleted objects
+if is_joined; then
+	if is_installed univention-samba4 2>&3; then
+		if [ -x "$(which samba-tool)" ]; then
+			# shellcheck disable=SC2154
+			samba-tool dbcheck --yes --fix "CN=Deleted Objects,CN=Configuration,$samba4_ldap_base" >&3 2>&3
+			samba-tool dbcheck --yes --fix "CN=Deleted Objects,DC=DomainDnsZones,$samba4_ldap_base" >&3 2>&3
+			samba-tool dbcheck --yes --fix "CN=Deleted Objects,DC=ForestDnsZones,$samba4_ldap_base" >&3 2>&3
+			samba-tool dbcheck --yes --fix "CN=Deleted Objects,$samba4_ldap_base" >&3 2>&3
+		fi
+	fi
+fi
+
+
 echo "
 
 
